@@ -21,25 +21,28 @@ if os.path.isfile('.env'):
 def cfg(name, default=None):
     """ Get config value by key """
 
-    if not sets or name.isupper():
-        name = name.replace('.', '_').upper()
-        value = os.getenv(name, default)
-
-        if value:
-            try:
-                value = json.loads(value)
-            except (json.decoder.JSONDecodeError, TypeError):
-                pass
-
-        return value
-
     keys = name.split('.')
     data = sets
 
     for key in keys:
         if key not in data:
-            return default
-
+            break
         data = data[key]
+    else:
+        return data
 
-    return data
+    name = name.replace('.', '_').upper()
+    value = os.getenv(name, default)
+
+    if value:
+        try:
+            value = json.loads(value)
+        except (json.decoder.JSONDecodeError, TypeError):
+            pass
+
+    return value
+
+
+def set_cfg(name, value):
+    """ Set config value """
+    sets[name] = value
